<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Conversa</translation>
    </message>
    <message>
        <source>Misspelled Words Marking Options</source>
        <translation>Opções de marcação de erros</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Negrito</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Itálico</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Sublinhado</translation>
    </message>
    <message>
        <source>Spell Checker Options</source>
        <translation>Opções do corretor ortográfico</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ignorar maiúsculas e minúsculas</translation>
    </message>
    <message>
        <source>Spelling Suggestions Options</source>
        <translation>Opções de sugestões de correção</translation>
    </message>
    <message>
        <source>Show suggestions</source>
        <translation>Mostrar sugestões</translation>
    </message>
    <message>
        <source>Maximum number of suggested words</source>
        <translation>Quantidade máxima de palavras sugeridas</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>Ortografia</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Could not find dictionary for %1 language.</source>
        <translation>Não foi possível encontrar o dicionário para o idioma %1.</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
</context>
<context>
    <name>SpellcheckerConfigurationUiHandler</name>
    <message>
        <source>Move to &apos;Checked&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Available languages</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Move to &apos;Available languages&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Checked</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>